@@ -890,7 +890,7 @@ def _create_random_displacements_at_finite_temperature(
             "(number of integrated modes):"
         )
         for q, integrated_modes, freqs in zip(
-            rd_comm_points, rd_integrated_modes, rd_frequencies
+            rd_comm_points, rd_integrated_modes, rd_frequencies, strict=True
         ):
             print(f"{q} ({integrated_modes.sum()})")
             if log_level > 1:
@@ -963,7 +963,7 @@ def store_nac_params(
                 print("         %12.7f %12.7f %12.7f" % tuple(v))
             print("-" * 26 + " Born effective charges " + "-" * 26)
             symbols = phonon.primitive.symbols
-            for i, (z, s) in enumerate(zip(nac_params["born"], symbols)):
+            for i, (z, s) in enumerate(zip(nac_params["born"], symbols, strict=True)):
                 for j, v in enumerate(z):
                     if j == 0:
                         text = "%5d %-2s" % (i + 1, s)
@@ -1009,7 +1009,7 @@ def _run_calculation(
         )
 
         if settings.is_hdf5 or settings.qpoints_format == "hdf5":
-            phonon.write_hdf5_qpoints_phonon()
+            phonon.write_hdf5_qpoints_phonon(compression=settings.hdf5_compression)
         else:
             phonon.write_yaml_qpoints_phonon()
 
@@ -1023,6 +1023,8 @@ def _run_calculation(
             npoints = settings.band_points
         band_paths = settings.band_paths
 
+        assert band_paths is not None
+
         if _is_band_auto(settings):
             print("SeeK-path is used to generate band paths.")
             print(
@@ -1035,6 +1037,13 @@ def _run_calculation(
                 is_const_interval=settings.is_band_const_interval,
             )
         else:
+            if isinstance(band_paths, str):
+                if log_level:
+                    msg = f'Incorrect band paths "{band_paths}" specified.'
+                    print_error_message(msg)
+                print_error()
+                sys.exit(1)
+
             is_legacy_plot = settings.is_legacy_plot
             if settings.is_band_const_interval:
                 reclat = np.linalg.inv(phonon.primitive.cell)
@@ -1057,8 +1066,13 @@ def _run_calculation(
             for band in bands:
                 print(
                     "[%6.3f %6.3f %6.3f] --> [%6.3f %6.3f %6.3f]"
-                    % (tuple(band[0]) + tuple(band[-1]))
+                    % (tuple(band[0]) + tuple(band[-1])),
+                    end="",
                 )
+                if settings.is_band_const_interval:
+                    print(f"   ({len(band)} points)")
+                else:
+                    print("")
 
         phonon.run_band_structure(
             bands,
@@ -1078,7 +1092,9 @@ def _run_calculation(
             }
 
         if settings.is_hdf5 or settings.band_format == "hdf5":
-            phonon.write_hdf5_band_structure(comment=comment)
+            phonon.write_hdf5_band_structure(
+                comment=comment, compression=settings.hdf5_compression
+            )
         else:
             phonon.write_yaml_band_structure(comment=comment)
 
@@ -1153,7 +1169,7 @@ def _run_calculation(
 
             if settings.write_mesh:
                 if settings.is_hdf5 or settings.mesh_format == "hdf5":
-                    phonon.write_hdf5_mesh()
+                    phonon.write_hdf5_mesh(compression=settings.hdf5_compression)
                 else:
                     phonon.write_yaml_mesh()
 
@@ -1210,7 +1226,7 @@ def _run_calculation(
                 fe = tp["free_energy"]
                 entropy = tp["entropy"]
                 heat_capacity = tp["heat_capacity"]
-                for T, F, S, CV in zip(temps, fe, entropy, heat_capacity):
+                for T, F, S, CV in zip(temps, fe, entropy, heat_capacity, strict=True):
                     print(("%12.3f " + "%15.7f" * 4) % (T, F, S, CV, F + T * S / 1000))
 
             if plot_conf["plot_graph"]:
