@@ -65,7 +65,7 @@ class Settings:
     def __init__(self, load_phonopy_yaml: bool = False):
         """Init method."""
         self.band_indices: list | None = None
-        self.band_paths: list[NDArray] | None = None
+        self.band_paths: list[NDArray] | Literal["auto"] | None = None
         self.band_points: int | None = None
         self.cell_filename: str | None = None
         self.chemical_symbols: list[str] | None = None
@@ -87,7 +87,7 @@ class Settings:
         self.frequency_conversion_factor = None
         self.frequency_scale_factor = None
         self.group_velocity_delta_q = None
-        self.hdf5_compression = "gzip"
+        self.hdf5_compression: Literal["gzip", "lzf"] | int | None = "gzip"
         self.is_band_const_interval = False
         self.is_diagonal_displacement = True
         self.is_eigenvectors = False
