@@ -42,6 +42,7 @@ import sys
 import typing
 import warnings
 from collections import OrderedDict
+from collections.abc import Sequence
 
 import numpy as np
 from numpy.typing import NDArray
@@ -63,7 +64,9 @@ from phonopy.structure.atoms import PhonopyAtoms, split_symbol_and_index, symbol
 from phonopy.structure.cells import Primitive, get_primitive, get_supercell
 
 
-def parse_set_of_forces(num_atoms, forces_filenames, verbose=True):
+def parse_set_of_forces(
+    num_atoms: int, forces_filenames: Sequence[str | os.PathLike], verbose: bool = True
+) -> list[NDArray] | list:
     """Parse forces from output files."""
     hook = "Forces acting on atoms"
     is_parsed = True
@@ -161,7 +164,7 @@ def write_supercells_with_displacements(
 ):
     """Write supercells with displacements to files."""
     write_pwscf("%s.in" % pre_filename, supercell, pp_filenames)
-    for i, cell in zip(ids, cells_with_displacements):
+    for i, cell in zip(ids, cells_with_displacements, strict=True):
         filename = "{pre_filename}-{0:0{width}}.in".format(
             i, pre_filename=pre_filename, width=width
         )
@@ -182,7 +185,7 @@ def get_pwscf_structure(cell, pp_filenames=None):
     chemical_symbols = cell.symbols
     unique_symbols = []
     atomic_species = []
-    for symbol, m in zip(chemical_symbols, masses):
+    for symbol, m in zip(chemical_symbols, masses, strict=True):
         if symbol not in unique_symbols:
             unique_symbols.append(symbol)
             atomic_species.append((symbol, m))
@@ -202,7 +205,11 @@ def get_pwscf_structure(cell, pp_filenames=None):
             lines += " %2s %10.5f   %s\n" % (symbol, mass, pp_filenames[symbol])
     lines += "ATOMIC_POSITIONS crystal\n"
     for i, (symbol, pos_line) in enumerate(
-        zip(chemical_symbols, get_scaled_positions_lines(positions).split("\n"))
+        zip(
+            chemical_symbols,
+            get_scaled_positions_lines(positions).split("\n"),
+            strict=True,
+        )
     ):
         lines += (" %2s " % symbol) + pos_line
         if i < len(chemical_symbols) - 1:
