@@ -163,7 +163,7 @@ class Animation:
         text = "# Phonopy generated file for v_sim 3.6\n"
         text += "%15.9f%15.9f%15.9f\n" % (lat[0, 0], lat[1, 0], lat[1, 1])
         text += "%15.9f%15.9f%15.9f\n" % (lat[2, 0], lat[2, 1], lat[2, 2])
-        for s, p in zip(self._symbols, self._positions_oriented):
+        for s, p in zip(self._symbols, self._positions_oriented, strict=True):
             text += "%15.9f%15.9f%15.9f %2s\n" % (p[0], p[1], p[2], s)
 
         for i, val in enumerate(self._eigenvalues):
@@ -272,7 +272,9 @@ class Animation:
             text += "%d\n" % len(self._symbols)
             text += "q %s , b %d , f %f " % (str(self._qpoint), i + 1, freq * _factor)
             text += "(generated by Phonopy)\n"
-            for s, p, u in zip(self._symbols, self._positions_oriented, displacements):
+            for s, p, u in zip(
+                self._symbols, self._positions_oriented, displacements, strict=True
+            ):
                 text += "%-3s  %22.15f %22.15f %22.15f  " % (s, p[0], p[1], p[2])
                 text += "%15.9f %15.9f %15.9f\n" % (u[0].real, u[1].real, u[2].real)
         w = open(filename, "w")
