@@ -2,16 +2,16 @@
 
 from __future__ import annotations
 
-import os
 from io import StringIO
+import pathlib
 
 import numpy as np
-
+import pathlib
 import phonopy
 from phonopy import Phonopy
 from phonopy.interface.vasp import read_vasp
 
-data_dir = os.path.dirname(os.path.abspath(__file__))
+data_dir = pathlib.Path(__file__).parent
 
 chars_P2 = """ 1.  0.  1.  0.
  1.  0. -1.  0.
@@ -757,6 +757,7 @@ def test_pt03_P2():
     data = _load_data(chars_P2)
     phonon = _get_phonon("P2", [3, 2, 2], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [[0, 0, 0.5]]  # V
@@ -769,6 +770,7 @@ def test_pt04_Pc():
     data = _load_data(chars_Pc)
     phonon = _get_phonon("Pc", [2, 2, 2], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [[0, 0.5, 0]]  # GA
@@ -781,6 +783,7 @@ def test_pt06_P222_1():
     data = _load_data(chars_P222_1)
     phonon = _get_phonon("P222_1", [2, 2, 1], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -801,6 +804,7 @@ def test_pt07_Amm2():
     data = _load_data(chars_Amm2)
     phonon = _get_phonon("Amm2", [3, 2, 2], [[1, 0, 0], [0, 0.5, -0.5], [0, 0.5, 0.5]])
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -819,6 +823,7 @@ def test_pt09_P4_1():
     data = _load_data(chars_P4_1)
     phonon = _get_phonon("P4_1", [2, 2, 1], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [[0, 0, 0.5]]
@@ -831,6 +836,7 @@ def test_pt10_Pbar4():
     data = _load_data(chars_Pbar4)
     phonon = _get_phonon("P-4", [1, 1, 2], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -849,6 +855,7 @@ def test_pt11_I4_1a():
         "I4_1a", [2, 2, 1], np.array([[-1, 1, 1], [1, -1, 1], [1, 1, -1]]) * 0.5
     )
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -868,6 +875,7 @@ def test_pt13_P4mm():
     data = _load_data(chars_P4mm)
     phonon = _get_phonon("P4mm", [3, 3, 2], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -886,6 +894,7 @@ def test_pt14_Pbar42_1m():
     data = _load_data(chars_Pbar42_1m)
     phonon = _get_phonon("P-42_1m", [2, 2, 3], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -906,6 +915,7 @@ def test_pt19_P3m1():
     data = _load_data(chars_P3m1)
     phonon = _get_phonon("P3m1", [4, 4, 2], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -923,6 +933,7 @@ def test_pt19_P31m():
     data = _load_data(chars_P31m)
     phonon = _get_phonon("P31m", [1, 1, 3], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     # _show_chars(chars)
     np.testing.assert_allclose(chars, data, atol=1e-5)
@@ -941,6 +952,7 @@ def test_pt20_Pbar3m1():
     data = _load_data(chars_Pbar3m1)
     phonon = _get_phonon("P-3m1", [3, 3, 2], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -961,6 +973,7 @@ def test_pt21_P6():
     data = _load_data(chars_P6)
     phonon = _get_phonon("P6", [2, 2, 1], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -978,6 +991,7 @@ def test_pt22_Pbar6():
     data = _load_data(chars_Pbar6)
     phonon = _get_phonon("P-6", [1, 1, 3], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -998,6 +1012,7 @@ def test_pt24_P6_222():
     data = _load_data(chars_P6_222)
     phonon = _get_phonon("P6_222", [2, 2, 2], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -1018,6 +1033,7 @@ def test_pt26_Pbar6m2():
     data = _load_data(chars_Pbar6m2)
     phonon = _get_phonon("P-6m2", [2, 2, 3], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -1036,8 +1052,8 @@ def test_pt26_Pbar62m():
     data = _load_data(chars_Pbar62m)
     phonon = _get_phonon("P-62m", [1, 1, 2], np.eye(3))
     phonon.set_irreps([0, 0, 0], degeneracy_tolerance=1e-4)
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
-    _show_chars(chars)
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
         [0, 0, 0.5],
@@ -1055,6 +1071,7 @@ def test_pt28_P2_13():
     data = _load_data(chars_P2_13)
     phonon = _get_phonon("P2_13", [2, 2, 2], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -1073,6 +1090,7 @@ def test_pt29_Pabar3():
     data = _load_data(chars_Pabar3)
     phonon = _get_phonon("Pa-3", [2, 2, 2], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -1116,6 +1134,7 @@ def test_pt30_P4_332():
     data = _load_data(chars_P4_332)
     phonon = _get_phonon("P4_332", [1, 1, 1], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -1159,6 +1178,7 @@ def test_pt31_Pbar43m():
     data = _load_data(chars_Pbar43m)
     phonon = _get_phonon("P-43m", [2, 2, 2], np.eye(3))
     phonon.set_irreps([0, 0, 0])
+    assert phonon.irreps is not None
     chars = phonon.irreps.characters
     np.testing.assert_allclose(chars, data, atol=1e-5)
     qpoints = [
@@ -1197,17 +1217,30 @@ def test_pt31_Pbar43m():
     _check_char_sum(phonon, qpoints)
 
 
-def _get_phonon(spgtype, dim, pmat):
-    cell = read_vasp(os.path.join(data_dir, "POSCAR_%s" % spgtype))
-    filename = os.path.join(data_dir, "FORCE_SETS_%s" % spgtype)
+def test_pt31_Pbar43m_Gamma():
+    """Test of pt31_Pbar43m."""
+    phonon = _get_phonon("P-43m", [2, 2, 2], np.eye(3), symmetrize_fc=True)
+    qpoints = [[0, 0, 0]]
+    _check_char_sum(phonon, qpoints)
+
+
+# def test_pt21_P6_Gamma():
+#     """Test of pt21_P6."""
+#     phonon = _get_phonon("P6", [2, 2, 1], np.eye(3), symmetrize_fc=True)
+#     qpoints = [[0, 0, 0]]
+#     _check_char_sum(phonon, qpoints)
+
+
+def _get_phonon(spgtype, dim, pmat, symmetrize_fc=False):
+    cell = read_vasp(pathlib.Path(data_dir / f"POSCAR_{spgtype}"))
+    filename = pathlib.Path(data_dir / f"FORCE_SETS_{spgtype}")
     phonon = phonopy.load(
         unitcell=cell,
         supercell_matrix=np.diag(dim),
         primitive_matrix=pmat,
         force_sets_filename=filename,
-        symmetrize_fc=False,
+        symmetrize_fc=symmetrize_fc,
     )
-    print(phonon.symmetry.pointgroup_symbol)
     return phonon
 
 
@@ -1223,14 +1256,22 @@ def _load_data(data_str):
     return data
 
 
-def _check_char_sum(phonon: Phonopy, qpoints: list):
-    print("space-group number:", phonon.symmetry.dataset.number)
+def _check_char_sum(phonon: Phonopy, qpoints: list, show_info: bool = False):
+    if show_info:
+        print()
+        print("space-group number:", phonon.symmetry.dataset.number)
+        print(phonon.symmetry.pointgroup_symbol)
+        assert phonon.irreps is not None
+        _show_chars(phonon.irreps.characters)
 
+    found_physically_irreps = False
     for q in qpoints:
         phonon.set_irreps(q)
-        print(phonon.irreps.qpoint, end="")
+        assert phonon.irreps is not None
+        # print(phonon.irreps.qpoint)
         order = len(phonon.irreps.conventional_rotations)
         char_sums = []
+        freqs = phonon.irreps.frequencies
         for i, (irreps, chars) in enumerate(
             zip(phonon.irreps.irreps, phonon.irreps.characters)
         ):
@@ -1242,15 +1283,20 @@ def _check_char_sum(phonon: Phonopy, qpoints: list):
             char_sum = abs(char_sum)
             dim = int(np.rint(char_sum / order))
             assert abs(char_sum - dim * order) < 1e-5
-            # print(i + 1, char_sum, order)
             assert dim in [1, 2, 4]
             if dim == 1:  # maybe physically irreducible (dim > 1)
                 char_sums.append(char_sum)
 
+            if show_info:
+                print(f"{i + 1}: sum|x|^2 {char_sum}, order {order}, dim {dim}")
+                print(f"freqs: {freqs[phonon.irreps.band_indices[i]]}")
+                print(chars)
+
         if char_sums:  # Can be empty due to physically irreducible irreps.
             np.testing.assert_allclose(char_sums, order, atol=1e-5)
 
         if len(char_sums) < len(phonon.irreps.irreps):
-            print("  ** Physically irreps may exist. **")
-        else:
-            print()
+            if not found_physically_irreps and not show_info:
+                print()
+            print(f"  Physically irreps may exist at {q}.")
+            found_physically_irreps = True
